@@ -33,6 +33,7 @@ class SumoClient:
         verbosity: str = "CRITICAL",
         retry_strategy=RetryStrategy(),
         timeout=DEFAULT_TIMEOUT,
+        case_uuid=None,
     ):
         """Initialize a new Sumo object
 
@@ -49,6 +50,9 @@ class SumoClient:
         if env not in APP_REGISTRATION:
             raise ValueError(f"Invalid environment: {env}")
 
+        self.env = env
+        self._verbosity = verbosity
+
         self._retry_strategy = retry_strategy
         self._client = httpx.Client()
         self._async_client = httpx.AsyncClient()
@@ -85,6 +89,7 @@ class SumoClient:
             refresh_token=refresh_token,
             access_token=access_token,
             devicecode=devicecode,
+            case_uuid=case_uuid,
         )
 
         if env == "localhost":
@@ -378,7 +383,7 @@ class SumoClient:
 
         return retryer(_delete)
 
-    def get_logger(self, name):
+    def getLogger(self, name):
         """Gets a logger object that sends log objects into the message_log
         index for the Sumo instance.
 
@@ -398,6 +403,35 @@ class SumoClient:
             pass
         return logger
 
+    def create_shared_access_key_for_case(self, case_uuid):
+        """Creates and stores a shared access key that can be used to access
+        the case identified by *case_uuid*, in the current Sumo environment.
+
+        This shared access key can then be used by instantiating
+        SumoClient with the parameter case_uuid set accordingly.
+
+        Args:
+            case_uuid: the uuid for a case.
+
+        Side effects:
+            Creates a new file in ~/.sumo, named {app_id}+{case_uuid}
+        """
+        token = self.get(
+            f"/objects('{case_uuid}')/make-shared-access-key"
+        ).text
+        self.auth.store_shared_access_key_for_case(case_uuid, token)
+
+    def client_for_case(self, case_uuid):
+        """Instantiate and return new SumoClient for accessing the
+        case identified by *case_uuid*."""
+        return SumoClient(
+            env=self.env,
+            verbosity=self._verbosity,
+            retry_strategy=self._retry_strategy,
+            timeout=self._timeout,
+            case_uuid=case_uuid,
+        )
+
     @raise_for_status_async
     async def get_async(self, path: str, params: dict = None):
         """Performs an async GET-request to the Sumo API.
